@@ -35,7 +35,8 @@ expand_path(struct xkb_context *ctx, const char* parent_file_name,
 FILE *
 FindFileInXkbPath(struct xkb_context *ctx, const char* parent_file_name,
                   const char *name, size_t name_len, enum xkb_file_type type,
-                  char *buf, size_t buf_size, unsigned int *offset);
+                  char *buf, size_t buf_size, unsigned int *offset,
+                  bool required);
 
 bool
 ExceedsIncludeMaxDepth(struct xkb_context *ctx, unsigned int include_depth);
